==> kdepim-4.12.5.tar.xz: kdepim-4.12.5/kontact/plugins/korganizer/apptsummarywidget.h <==
/*
  This file is part of Kontact.

  Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>
  Copyright (c) 2005-2006,2008-2009 Allen Winter <winter@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

  As a special exception, permission is given to link this program
  with any edition of Qt, and distribute the resulting executable,
  without including the source code for Qt in the source distribution.
*/

#ifndef SUMMARYWIDGET_H
#define SUMMARYWIDGET_H

#include <Akonadi/Calendar/ETMCalendar>

#include <KontactInterface/Summary>

class KOrganizerPlugin;


namespace Akonadi {
  class Item;
  class IncidenceChanger;
}

class QDate;
class QGridLayout;
class QLabel;

class ApptSummaryWidget : public KontactInterface::Summary
{
  Q_OBJECT

  public:
    ApptSummaryWidget( KOrganizerPlugin *plugin, QWidget *parent );
    ~ApptSummaryWidget();

    int summaryHeight() const { return 3; }
    QStringList configModules() const;
    void configUpdated();
    void updateSummary( bool force = false )
    {
      Q_UNUSED( force );
      updateView();
    }

  protected:
    virtual bool eventFilter( QObject *obj, QEvent *e );

  private slots:
    void updateView();
    void popupMenu( const QString &uid );
    void viewEvent( const QString &uid );
    void removeEvent( const Akonadi::Item &item );

  private:
    void dateDiff( const QDate &date, int &days );

    Akonadi::ETMCalendar::Ptr mCalendar;
    Akonadi::IncidenceChanger *mChanger;

    QGridLayout *mLayout;
    QList<QLabel *> mLabels;
    KOrganizerPlugin *mPlugin;
    int mDaysAhead;
    bool mShowBirthdaysFromCal;
    bool mShowAnniversariesFromCal;
    bool mShowMineOnly;
};

#endif

==> kdepim_4.13.0.orig.tar.xz: kdepim-4.13.0/kontact/plugins/korganizer/apptsummarywidget.h <==
/*
  This file is part of Kontact.

  Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>
  Copyright (c) 2005-2006,2008-2009 Allen Winter <winter@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

  As a special exception, permission is given to link this program
  with any edition of Qt, and distribute the resulting executable,
  without including the source code for Qt in the source distribution.
*/

#ifndef SUMMARYWIDGET_H
#define SUMMARYWIDGET_H

#include <KontactInterface/Summary>

class KOrganizerPlugin;


namespace Akonadi {
  class Item;
  class IncidenceChanger;
  class ETMCalendar;
}

class QDate;
class QGridLayout;
class QLabel;

class ApptSummaryWidget : public KontactInterface::Summary
{
  Q_OBJECT

  public:
    ApptSummaryWidget( KOrganizerPlugin *plugin, QWidget *parent );
    ~ApptSummaryWidget();

    int summaryHeight() const { return 3; }
    QStringList configModules() const;
    void configUpdated();
    void updateSummary( bool force = false )
    {
      Q_UNUSED( force );
      updateView();
    }

  protected:
    virtual bool eventFilter( QObject *obj, QEvent *e );

  private slots:
    void updateView();
    void popupMenu( const QString &uid );
    void viewEvent( const QString &uid );
    void removeEvent( const Akonadi::Item &item );

  private:
    void dateDiff( const QDate &date, int &days );

    Akonadi::ETMCalendar *mCalendar;
    Akonadi::IncidenceChanger *mChanger;

    QGridLayout *mLayout;
    QList<QLabel *> mLabels;
    KOrganizerPlugin *mPlugin;
    int mDaysAhead;
    bool mShowBirthdaysFromCal;
    bool mShowAnniversariesFromCal;
    bool mShowMineOnly;
};

#endif
